@@ -5,10 +5,16 @@
 """
 
 from argparse import ArgumentParser
+from importlib import import_module
 from os import path
 
-import cdd_gae.ndb2sqlalchemy
+import cdd.gen_utils
+import cdd.source_transformer
+from cdd.__main__ import parse_emit_types
+
 import cdd_gae.ndb2sqlalchemy_migrator
+import cdd_gae.parse.ndb
+import cdd_gae.parse.parquet
 import cdd_gae.webapp2_to_fastapi
 from cdd_gae import __description__, __version__
 
@@ -34,26 +40,42 @@ def _build_parser():
     subparsers.required = True
     subparsers.dest = "command"
 
-    ##################
-    # ndb2sqlalchemy #
-    ##################
-    ndb2sqlalchemy_parser = subparsers.add_parser(
-        "ndb2sqlalchemy",
-        help="Parse NDB emit SQLalchemy",
+    #######
+    # gen #
+    #######
+    gen_parser = subparsers.add_parser(
+        "gen", help="Go from cdd_gae supported parse type to cdd supported emit type"
     )
-    ndb2sqlalchemy_parser.add_argument(
+    gen_parser.add_argument(
+        "--parse",
+        help="What type the input is.",
+        choices=("ndb", "parquet", "webapp2"),
+        dest="parse_name",
+    )
+    gen_parser.add_argument(
+        "--emit",
+        help="What type to generate.",
+        choices=parse_emit_types,
+        required=True,
+        dest="emit_name",
+    )
+    gen_parser.add_argument(
         "-i",
         "--input-file",
         help="Python file to parse NDB `class`es out of",
         required=True,
     )
-    ndb2sqlalchemy_parser.add_argument(
+    gen_parser.add_argument(
         "-o",
         "--output-file",
         help="Empty file to generate SQLalchemy classes to",
         required=True,
     )
-    ndb2sqlalchemy_parser.add_argument(
+    gen_parser.add_argument(
+        "--name",
+        help="Name of function/class to emit, defaults to inferring from filename",
+    )
+    gen_parser.add_argument(
         "--dry-run",
         help="Show what would be created; don't actually write to the filesystem.",
         action="store_true",
@@ -98,31 +120,6 @@ def _build_parser():
         action="store_true",
     )
 
-    ######################
-    # webapp2_to_fastapi #
-    ######################
-    webapp2_to_fastapi_parser = subparsers.add_parser(
-        "webapp2_to_fastapi",
-        help="Parse WebApp2 emit FastAPI",
-    )
-    webapp2_to_fastapi_parser.add_argument(
-        "-i",
-        "--input-file",
-        help="Python file to parse WebApp2 `class`es out of",
-        required=True,
-    )
-    webapp2_to_fastapi_parser.add_argument(
-        "-o",
-        "--output-file",
-        help="Empty file to generate FastAPI functions to",
-        required=True,
-    )
-    webapp2_to_fastapi_parser.add_argument(
-        "--dry-run",
-        help="Show what would be created; don't actually write to the filesystem.",
-        action="store_true",
-    )
-
     return parser
 
 
@@ -147,14 +144,63 @@ def main(cli_argv=None, return_args=False):
 
     command = args.command
     args_dict = {k: v for k, v in vars(args).items() if k != "command"}
-    if command in frozenset(("ndb2sqlalchemy", "webapp2_to_fastapi")):
+    if command == "gen":
         require_file_existent(_parser, args_dict["input_file"], name="input-file")
 
-        return (
-            cdd_gae.webapp2_to_fastapi.webapp2_to_fastapi_file
-            if command == "webapp2_to_fastapi"
-            else cdd_gae.ndb2sqlalchemy.ndb2sqlalchemy
-        )(**args_dict)
+        if args_dict["parse_name"] == "webapp2":
+            assert args_dict["emit_name"] == "fastapi", '{} != "fastapi"'.format(
+                args_dict["emit_name"]
+            )
+            for key in "parse_name", "emit_name", "name":
+                del args_dict[key]
+            return cdd_gae.webapp2_to_fastapi.webapp2_to_fastapi_file(**args_dict)
+
+        ir = (
+            {"parquet": cdd_gae.parse.parquet.parquet, "ndb": cdd_gae.parse.ndb.ndb}[
+                args_dict["parse_name"]
+            ]
+        )(args_dict["input_file"], name=args_dict["name"])
+        global__all__ = []
+        mod = cdd.gen_utils.gen_module(
+            decorator_list=[],
+            emit_and_infer_imports=True,
+            emit_call=True,
+            emit_default_doc=True,
+            emit_name=args_dict["emit_name"],
+            functions_and_classes=(
+                print("\nGenerating: {name!r}".format(name=ir["name"]))
+                or global__all__.append(ir["name"])
+                or (
+                    getattr(
+                        import_module(
+                            ".".join(("cdd", "emit", args_dict["emit_name"]))
+                        ),
+                        args_dict["emit_name"],
+                    )(
+                        ir,
+                        emit_default_doc=True,
+                        word_wrap=True,
+                        **cdd.gen_utils.get_emit_kwarg(
+                            decorator_list=[],
+                            emit_call=True,
+                            emit_name=args_dict["emit_name"],
+                            name_tpl="{name}",
+                            name=ir["name"],
+                        ),
+                    ),
+                )
+            ),
+            imports="",
+            input_mapping_it=dict(),
+            name_tpl="{name}",
+            no_word_wrap=False,
+            parse_name="",
+            prepend=None,
+            global__all__=global__all__,
+        )
+        with open(args_dict["output_file"], "wt") as f:
+            f.write(cdd.source_transformer.to_code(mod))
+
     else:
         assert command == "ndb2sqlalchemy_migrator"
         return cdd_gae.ndb2sqlalchemy_migrator.ndb2sqlalchemy_migrator_folder(
